..
    Copyright (C) 2022 CERN.

    Invenio-RDM-Migrator is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

InvenioRDM module for data migration.

- CERN <info@inveniosoftware.org>

